@@ -360,7 +360,6 @@ class DataPlotterCallback(Callback):
                 
         dtype = self.trainer.network_dtype
         
-        #self.trainer.network.eval()
 
         for input_real, output_real in self.inputs_outputs_real:
             inputs_real.append(input_real)
@@ -368,11 +367,16 @@ class DataPlotterCallback(Callback):
 
             input_real = self.trainer.to_tensor([input_real], dtype=dtype)
             
-            output_fake = self.trainer.network(input_real)
+            self.trainer.network.eval()
+            with torch.set_grad_enabled(False):
+                output_fake = self.trainer.network(input_real)   
+            self.trainer.network.train()
+
             output_fake = output_fake[0]
             output_fake = self.trainer.to_numpy(output_fake)
             
             outputs_fake.append(output_fake)
+        
 
         inputs_real = np.asarray(inputs_real)
         outputs_real = np.asarray(outputs_real)
