@@ -122,6 +122,7 @@ class AbstractNnTrainer(object):
         self._batch_size = batch_size
         self._model_directory_path = make_path(os.path.join(output_dir, "{}_{}".format(datetime.datetime.now().strftime("%Y%m%d%H%M%S"), self.__class__.__name__))) 
         self._generator_model_directory_path = make_path(os.path.join(self._model_directory_path, self._net_g.__class__.__name__))
+        self._most_recent_epoch_index_trained = 0
 
     @property
     def device(self):
@@ -163,6 +164,16 @@ class AbstractNnTrainer(object):
         """
         return self._model_directory_path
     
+    @property
+    def most_recent_epoch_index_trained(self):
+        """
+        Gets the most recent epoch index this trainer trained model(s) on
+
+        Returns:
+            int: The epoch index last trained
+        """
+        return self._most_recent_epoch_index_trained
+
     def to_tensor(self, data:Any, dtype=torch.float32):
         """
         A utility method for converting data to tensor objects 
@@ -232,7 +243,20 @@ class AbstractNnTrainer(object):
         """
         raise NotImplementedError("train method must be implemented")
 
-    def save_model(self, model_name):
+    @abstractmethod
+    def save_models(self) -> List[str]:
+        """        
+        Saves all models used by this trainer
+
+        Raises:
+            NotImplementedError: [description]
+
+        Returns:
+            List[str]: A list of paths for each model saved
+        """
+        raise NotImplementedError("train method must be implemented")
+
+    def _save_model(self, directory:str, model_name:str):
         """Saving the model.  This method reuses the model output directory property 
         initialized during construction of this object.
         Parameters
@@ -244,7 +268,7 @@ class AbstractNnTrainer(object):
         str
             input filepath with ".pt" appended
         """
-        path = self.output_directory_path + "\\{}".format(model_name)
+        path = directory + f"\\{model_name}"
 
         saved_params = {}
         init_params = {}
