@@ -15,6 +15,8 @@ import torch.utils.data as td
 
 from typing import Dict
 
+from nn_trainer.utils import make_path
+
 class BasicNnTrainer(AbstractNnTrainer):
     """
     Basic implementation of a neural network trainer using residual loss calculation
@@ -128,6 +130,7 @@ class BasicNnTrainer(AbstractNnTrainer):
         self._callback_container.on_train_begin()
         
         for epoch_index in range(self._epoch_count):
+            self._most_recent_epoch_index_trained = epoch_index
             self._callback_container.on_epoch_begin(epoch_index)
             self._net_g.train()
             
@@ -173,6 +176,12 @@ class BasicNnTrainer(AbstractNnTrainer):
         self._callback_container.on_train_end()
         self.network.eval()
        
+    def save_models(self):
+        generator_output_directory = self.output_directory_path + '\\Generator'
+        make_path(generator_output_directory)
+        modelG = self._save_model(generator_output_directory, f'epoch_{self.most_recent_epoch_index_trained}_{self._net_g.__class__.__name__}')
+        return [ modelG ]
+
     def _set_callbacks(self, custom_callbacks):
         """Setup the callbacks functions.
         Parameters
