@@ -153,6 +153,7 @@ class VanillaGanNnTrainer(AbstractNnTrainer):
         self._callback_container.on_train_begin()
         
         for epoch_index in range(self._epoch_count):
+            self._most_recent_epoch_index_trained = epoch_index
             self._callback_container.on_epoch_begin(epoch_index)
             self._net_g.train()
             self._net_d.train()
@@ -230,7 +231,22 @@ class VanillaGanNnTrainer(AbstractNnTrainer):
         self._callback_container.on_train_end()
         self._net_g.eval()
         self._net_d.eval()
-       
+
+    def save_models(self):
+        """
+        Saves all models associated with this trainer
+
+        Returns:
+            List[str]: List of paths associated with each model saved
+        """
+        netG_output_directory = self.output_directory_path + '\\Generator'
+        netD_output_directory = self.output_directory_path + '\\Discriminator'
+        make_path(netG_output_directory)
+        make_path(netD_output_directory)
+        modelG = self._save_model(netG_output_directory, f'epoch_{self.most_recent_epoch_index_trained}_{self._net_g.__class__.__name__}')
+        modelD = self._save_model(netD_output_directory, f'epoch_{self.most_recent_epoch_index_trained}_{self._net_d.__class__.__name__}')
+        return [ modelG, modelD ]
+
     def _set_callbacks(self, custom_callbacks):
         """Setup the callbacks functions.
         Parameters
@@ -262,4 +278,6 @@ class VanillaGanNnTrainer(AbstractNnTrainer):
         if custom_callbacks:
             callbacks.extend(custom_callbacks)
         self._callback_container = CallbackContainer(callbacks)
-        self._callback_container.set_trainer(self)
\ No newline at end of file
+        self._callback_container.set_trainer(self)
+
+        
\ No newline at end of file
