@@ -138,6 +138,7 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
         # Call method on_train_begin for all callbacks
         self._callback_container.on_train_begin()
         for epoch_index in range(self._epoch_count):
+            self._most_recent_epoch_index_trained = epoch_index
             self._callback_container.on_epoch_begin(epoch_index)
             self._net_g.train()
             self._net_d.train()
@@ -219,6 +220,21 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
         self._net_g.eval()
         self._net_d.eval()
     
+    def save_models(self):
+        """
+        Saves all models associated with this trainer
+
+        Returns:
+            List[str]: List of paths associated with each model saved
+        """
+        netG_output_directory = self.output_directory_path + '\\Generator'
+        netD_output_directory = self.output_directory_path + '\\Discriminator'
+        make_path(netG_output_directory)
+        make_path(netD_output_directory)
+        modelG = self._save_model(netG_output_directory, f'epoch_{self.most_recent_epoch_index_trained}_{self._net_g.__class__.__name__}')
+        modelD = self._save_model(netD_output_directory, f'epoch_{self.most_recent_epoch_index_trained}_{self._net_d.__class__.__name__}')
+        return [ modelG, modelD ]
+
     def sample_generator(self, inputs):
         generated_data = self._net_g(inputs)
         return generated_data
